Uid0001 class

Inheritance

Constructors

Uid0001({required File inputFile, File? outputFile, Toolchain toolchain = const Toolchain()})
Creates a new Uid0001.

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The converter ID.
no setteroverride
inputFile File
The input file.
finalinherited
outputFile File?
The output file.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolchain Toolchain
Toolchain for required binaries.
finalinherited

Methods

audio() Future<void>
Convert a video.
override
image() Future<void>
Convert a video.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
text() Future<void>
Convert a video.
override
toString() String
A string representation of this object.
inherited
video() Future<void>
Convert a video.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited