Toolchain class
Toolchain for required binaries.
Constructors
- Toolchain({String binPathFfmpeg = defaultBinPathFfmpeg, String binPathFfprobe = defaultBinPathFfprobe, String binPathFfmpegYp3Patch = defaultBinPathFfmpegYp3Patch, String binPathImageMagick = defaultBinPathImageMagick, String binPathEbookConvert = defaultBinPathEbookConvert, String binPathMp4box = defaultBinPathMp4box})
-
Creates a new Toolchain.
const
Properties
- binPathEbookConvert → String
-
Binary path for ebook-convert.
final
- binPathFfmpeg → String
-
Binary path for FFmpeg.
final
- binPathFfmpegYp3Patch → String
-
Binary path for FFmpeg with YP3 x264 patch.
final
- binPathFfprobe → String
-
Binary path for FFprobe.
final
- binPathImageMagick → String
-
Binary path for Image Magick.
final
- binPathMp4box → String
-
Binary path for MP4Box.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
ebookConvert(
List< String> args) → Future<ProcessResult> - Calibre ebook-convert.
-
ffmpeg(
List< String> args) → Future<ProcessResult> - FFmpeg.
-
ffmpegYp3Patch(
List< String> args) → Future<ProcessResult> - FFmpeg with YP3 x264 patch.
-
ffprobe(
List< String> args) → Future<ProcessResult> - FFprobe.
-
imageMagick(
List< String> args) → Future<ProcessResult> - Image Magick.
-
mp4Box(
List< String> args) → Future<ProcessResult> - MP4Box.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
String executable, List< String> args) → Future<ProcessResult> - Run a process and return the exit code. Write to stdout and stderr.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- defaultBinPathEbookConvert → const String
- Default binary path for ebook-convert.
- defaultBinPathFfmpeg → const String
- Default binary path for FFmpeg.
- defaultBinPathFfmpegYp3Patch → const String
- Default binary path for FFmpeg with YP3 x264 patch.
- defaultBinPathFfprobe → const String
- Default binary path for FFprobe.
- defaultBinPathImageMagick → const String
- Default binary path for Image Magick.
- defaultBinPathMp4box → const String
- Default binary path for MP4Box.